////////////////////////////////////////////////////////////////////////////////
// The WebSearch() function will perform a callbook search for us. The two
// parameters that get passed in are the event that triggered this function
// call, and the type of search to perform.
////////////////////////////////////////////////////////////////////////////////
function WebSearch(event, type)
{
    // This variable will hold the URL we will browse to
    var URL = "";

    // This variable will tell us whether our search box is empty or not
    var isEmpty = false;

    // Get a handle to our search terms box
    var searchTermsBox = document.getElementById("OnlineCallbook-CallsignBox");
    
    // Get the value in the search terms box, trimming whitespace as necessary
    // See the TrimString() function farther down in this file for details
    // on how it works.
    var searchTerms = TrimString(searchTermsBox.value);

    if(searchTerms.length == 0) // Is the search terms box empty?
        isEmpty = true;         // If so, set the isEmpty flag to true
    else                        // If not, convert the terms to a URL-safe string
        searchTerms = ConvertTermsToURI(searchTerms);

    // Now switch on whatever the incoming type value is
    // If the search box is empty, we simply redirect the user to the appropriate
    // place at the Google website. Otherwise, we search for whatever they entered.

    switch(type)
    {
    // Build up the URL for a web search
    case "qsl":
        if(isEmpty) { URL = "http://www.qrz.com/qsl/"; }
        else        { URL = "http://www.qrz.com/qsl/?callsign=" + searchTerms; }
        break;
    case "hamcall":
        if(isEmpty) { URL = "http://www.buck.com/"; }
        else        { URL = "http://www.buck.com/cgi-bin/do_hamcallexe?call=" + searchTerms; }
        break;
    case "arrl":
        if(isEmpty) { URL = "http://www.arrl.org/"; }
        else        { URL = "http://www.arrl.org/fcc/fcclook.php3?call=" + searchTerms; }
        break;
    case "rac":
        if(isEmpty) { URL = "http://www.rac.ca/"; }
        else        { URL = "http://www.rac.ca/cgi-bin/cgiwrap/rac/callbook?QueryText=" + searchTerms + "&QueryType=call&perpage=25"; }
        break;
    case "qrzru":
        if(isEmpty) { URL = "http://www.qrz.ru/"; }
        else        { URL = "http://www.qrz.ru/callsign.phtml?callsign=" + searchTerms; }
        break;
    case "ric":
        if(isEmpty) { URL = "http://ric.cqham.ru/"; }
        else        { URL = "http://ric.cqham.ru/search.php?c=" + searchTerms +"&t=a;"; }
        break;
    case "qrz":
    default:
        if(isEmpty) { URL = "http://www.qrz.com/db/"; }
        else        { URL = "http://www.qrz.com/db/" + searchTerms; }
        break;
    }
    
    // Load the URL in the browser window using the TutTB_LoadURL function
    OpenTargetURL(URL);
}

////////////////////////////////////////////////////////////////////////////////
// The TrimString() function will trim all leading and trailing whitespace
// from the incoming string, and convert all runs of more than one whitespace
// character into a single space. The altered string gets returned.
////////////////////////////////////////////////////////////////////////////////
function TrimString(string)
{
    // If the incoming string is invalid, or nothing was passed in, return empty
    if (!string)
        return "";

    string = string.replace(/^\s+/, ''); // Remove leading whitespace
    string = string.replace(/\s+$/, ''); // Remove trailing whitespace

    // Replace all whitespace runs with a single space
    string = string.replace(/\s+/g, ' ');

    return string; // Return the altered value
}

////////////////////////////////////////////////////////////////////////////////
// The TutTB_ConvertTermsToURI() function converts an incoming string of search
// terms to a safe value for passing into a URL.
////////////////////////////////////////////////////////////////////////////////
function ConvertTermsToURI(terms)
{
    // Create an array to hold each search term
    var termArray = new Array();

    // Split up the search term string based on the space character
    termArray = terms.split(" ");

    // Create a variable to hold our resulting URI-safe value
    var result = "";

    // Loop through the search terms
    for(var i=0; i<termArray.length; i++)
    {
        // All search terms (after the first one) are to be separated with a '+'
        if(i > 0)
            result += "+";

        // Encode each search term, using the built-in Firefox function
        // encodeURIComponent().
        result += encodeURIComponent(termArray[i]);
    }

    return result; // Return the result
}

////////////////////////////////////////////////////////////////////////////////
// The LoadURL() function loads the specified URL in the browser.
////////////////////////////////////////////////////////////////////////////////
function OpenTargetURL(url)
{
    // Set the browser window's location to the incoming URL
    window._content.document.location = url;

    // Make sure that we get the focus
    window.content.focus();
}

////////////////////////////////////////////////////////////////////////////////
// The TutTB_KeyHandler() function checks to see if the key that was pressed
// is the [Enter] key. If it is, a web search is performed.
////////////////////////////////////////////////////////////////////////////////
function EditBoxKeyHandler(event)
{
    // Was the key that was pressed [ENTER]? If so, perform a web search.
    if(event.keyCode == event.DOM_VK_RETURN)
        WebSearch(event, 'qrz');
}

function OpenAboutDialog()
{
    var newwindow=window.open('chrome://onlinecallbook/content/about.html','About Online Callbook','chrome,modal,centerscreen,dialog,height=220,width=350');
    if (window.focus) 
    {
      newwindow.focus();
    }
}